@@ -30,6 +30,10 @@
 
 #include <curses.h>
 
+#ifdef NCURSES_VERSION
+#include <string.h>
+#endif
+
 static SCREEN *ncu_screen;
 
 void
@@ -55,6 +59,26 @@ ncu_init()
 	/* enable extra keys */
 	keypad(stdscr, true);
 
+#ifdef NCURSES_VERSION
+	/* define Alt-* keys which for some reasons aren't defined by
+	   default (tested with ncurses 6.1 on Linux) */
+
+	if (!key_defined("M-^@")) {
+		char buffer[8];
+		buffer[0] = 033;
+
+		for (int i = 0x80; i <= 0xff; ++i) {
+			const char *name = keyname(i);
+			if (name != nullptr && name[0] == 'M' &&
+			    name[1] == '-' && name[2] != 0 &&
+			    (name[3] == 0 || name[4] == 0)) {
+				strcpy(buffer + 1, name + 2);
+				define_key(buffer, i);
+			}
+		}
+	}
+#endif
+
 	/* initialize mouse support */
 #ifdef HAVE_GETMOUSE
 	if (options.enable_mouse)
